%define momorel 1

Summary: Utilities for managing the second extended (ext2) filesystem.
Name: e2fsprogs
Version: 1.35
Release: %{momorel}m
License: GPL
Group: System Environment/Base
%NoSource 0 http://us.dl.sourceforge.net/%{name}/%{name}-%{version}.tar.gz 8d25ffd60d405ef32d341704a2323807
Patch1: reiserfs_uncheck.patch
Patch2: e2fsprogs-1.19-mountlabel3.patch
Patch3: e2fsprogs-1.23-blkgetsize64.patch
Patch4: e2fsprogs-1.27-nostrip.patch
Patch5: e2fsprogs-1.32-nosync.patch

Url: http://e2fsprogs.sourceforge.net/
BuildRoot: %{_tmppath}/%{name}-%{version}-root

%description
The e2fsprogs package contains a number of utilities for creating,
checking, modifying, and correcting any inconsistencies in second
extended (ext2) filesystems. E2fsprogs contains e2fsck (used to
repair filesystem inconsistencies after an unclean shutdown), mke2fs
(used to initialize a partition to contain an empty ext2 filesystem),
debugfs (used to examine the internal structure of a filesystem, to
manually repair a corrupted filesystem, or to create test cases for
e2fsck), tune2fs (used to modify filesystem parameters), and most of
the other core ext2fs filesystem utilities.

You should install the e2fsprogs package if you need to manage the
performance of an ext2 filesystem.

%package devel
Summary: Ext2 filesystem-specific static libraries and headers.
Group: Development/Libraries
Requires: e2fsprogs = %{version}
Prereq: info

%description devel
E2fsprogs-devel contains the libraries and header files needed to
develop second extended (ext2) filesystem-specific programs.

You should install e2fsprogs-devel if you want to develop ext2
filesystem-specific programs. If you install e2fsprogs-devel, you'll
also want to install e2fsprogs.

%prep
%setup -q
%patch1 -p1 -b .reiserfs_uncheck
#%patch2 -p1
%patch4 -p1
%patch5 -p1
chmod 644 po/*.po

%build
%configure --enable-elf-shlibs --enable-nls
make
make -C po

%install
rm -rf %{buildroot}
export PATH=/sbin:$PATH
make install install-libs DESTDIR="%{buildroot}" \
	root_sbindir=/sbin root_libdir=/lib
make install -C po DESTDIR="%{buildroot}"

# prepare documents
for dir in debugfs e2fsck ext2ed misc resize util; do
    cp -pf $dir/ChangeLog ChangeLog.$dir
done

for dir in "" e2p et evms ext2fs ss uuid; do
    cp -pf lib/${dir}/ChangeLog ChangeLog.lib${dir}
done

cp -pf ext2ed/README README.ext2ed
cp -af ext2ed/doc ext2ed.doc

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post devel
/sbin/install-info %{_infodir}/libext2fs.info.* %{_infodir}/dir
exit 0

%postun devel
if [ $1 = 0 ]; then
   /sbin/install-info --delete %{_infodir}/libext2fs.info.* %{_infodir}/dir
fi
exit 0

%files
%defattr(-,root,root)
%doc README* RELEASE-NOTES ChangeLog* ext2ed.doc

/sbin/*
%{_sbindir}/mklost+found
%{_sbindir}/filefrag

/lib/*.so.*
/lib/evms

%{_bindir}/chattr
%{_bindir}/lsattr
%{_bindir}/uuidgen
%{_mandir}/man1/chattr.1*
%{_mandir}/man1/lsattr.1*
%{_mandir}/man1/uuidgen.1*

%{_mandir}/man3/libuuid.3*
%{_mandir}/man3/uuid_clear.3*
%{_mandir}/man3/uuid_compare.3*
%{_mandir}/man3/uuid_copy.3*
%{_mandir}/man3/uuid_generate.3*
%{_mandir}/man3/uuid_generate_random.3*
%{_mandir}/man3/uuid_generate_time.3*
%{_mandir}/man3/uuid_is_null.3*
%{_mandir}/man3/uuid_parse.3*
%{_mandir}/man3/uuid_time.3*
%{_mandir}/man3/uuid_unparse.3*

%{_mandir}/man8/*

%{_datadir}/locale/*/*/*

%files devel
%defattr(-,root,root)
%{_infodir}/libext2fs.info*
%{_bindir}/compile_et
%{_bindir}/mk_cmds

%{_libdir}/*.a
%{_libdir}/*.so

/usr/share/et
/usr/share/ss
%{_includedir}/*
%{_mandir}/man1/compile_et.1*
%{_mandir}/man1/mk_cmds.1*
%{_mandir}/man3/com_err.3*
%{_mandir}/man3/libblkid.3*

%changelog
* Wed Mar 17 2004 YAMAZAKI Makoto <zaki@zakky.org>
- (1.35-1m)
- update to 1.35

* Wed Mar 17 2004 Toru Hoshina <t@momonga-linux.org>
- (1.34-2m)
- revised spec for enabling rpm 4.2.

* Mon Aug 25 2003 Masahiro Takahata <takahata@momonga-linux.org>
- (1.34-1m)
- update to 1.34

* Mon Mar 17 2003 KOMATSU Shinichiro <koma2@momonga-linux.org>
- (1.32-1m)
- update to 1.32
- unapply e2fsprogs-1.19-mountlabel3.patch
  (I am not sure whether it is still needed). 
- use * and macros in %%files section
- add more documents

* Wed Oct 30 2002 KOMATSU Shinichiro <koma2@jiro.c.u-tokyo.ac.jp>
- (1.29-1m)
- update to 1.29
- s/telia/us/

* Tue Apr 30 2002 Kenta MURATA <muraken@kondara.org>
- (1.27-6k)
- omit /sbin/ldconfig in PreReq.
- /sbin/install-info -> info in PreReq.

* Mon Apr  8 2002 Toru Hoshina <t@@kondara.org>
- (1.27-4k)
- a couple of commands lost.

* Wed Mar 20 2002 Tsutomu Yasuda <tom@kondara.org>
- (1.27-2k)
- update to 1.27

* Fri May  4 2001 YAMAGUCHI Kenji <yamk@kondara.org>
- (1.19-8k)
- merged RedHat esfsprogs-1.19-4.src.rpm patches for mountlabel.
- append URL:
- %{_tmppath}

* Wed Oct 25 2000 MATSUDA, Daiki <dyky@df-usa.com>
- modifiled %post and %preun section from .gz to .bz2

* Tue Aug 30 2000 Kazuhiko <kazuhiko@kondara.org>
- version 1.19
- remove e2fsprogs-debugfsy2k.patch
- add fsck.ext3, resize2fs, resize2fs.8*

* Sat Jul  8 2000 Toru Hoshina <t@kondara.org>
- rebuild against glibc-2.1.90, X-4.0, rpm-3.0.5.

* Sat Jun  3 2000 MATSUDA, Daiki <dyky@df-usa.com>
- uncheck fsck.reiserfs

* Sun Apr 02 2000 Takaaki Tabuchi <tab@kondara.org>
- merge redhat6.2(Release 5)
- add patch, Prereq, post devel , postun devel.

* Wed Mar 1 2000 Masako Hattori <maru@kondara.org>
- change jman mv->cp

* Wed Feb 23 2000 Masako Hattori <maru@kondara.org>
- do not shake %{_mandir}/ja

* Sat Feb  5 2000 Bill Nottingham <notting@redhat.com>
- add install-info scripts

* Thu Feb 03 2000 Elliot Lee <sopwith@redhat.com>
- Fix bug #8585 (Y2K problems in debugfs)

* Wed Feb 02 2000 Jakub Jelinek <jakub@redhat.com>
- allow multiline errors in et, so that other programs
  can use compile_et (from Kerberos)

* Tue Feb 1 2000 Masako Hattori <maru@kondara.org>
- add man-pages-ja-e2fsprogs-20000115

* Thu Jan 13 2000 Jeff Johnson <jbj@redhat.com>
- build 1.18 for 6.2.

* Sun Nov 28 1999 Masako Hattori <maru@kondara.org>
- add man-pages-ja-e2fsprogs-19991115

* Thu Nov 18 1999 Norihito Ohmori <nono@kondara.org>
- be a NoSrc :-P

* Tue Oct 26 1999 Bill Nottingham <notting@redhat.com>
- update to 1.17

* Mon Oct 25 1999 Bill Nottingham <notting@redhat.com>
- update to 1.16

* Thu Oct 21 1999 Bill Nottingham <notting@redhat.com>
- add patch to fix SIGUSR1 kills.

* Mon Oct 04 1999 Cristian Gafton <gafton@redhat.com>
- rebuild against new glibc in the sparc tree

* Thu Sep 23 1999 Jakub Jelinek <jakub@redhat.com>
- update mke2fs man page so that it reflects changes in mke2fs
  netweem 1.14 and 1.15

* Thu Aug  5 1999 Bill Nottingham <notting@redhat.com>
- fix lsattr on alpha

* Thu Jul 29 1999 Jeff Johnson <jbj@redhat.com>
- update to 1.15.

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com> 
- auto rebuild in the new build environment (release 4)

* Tue Mar 16 1999 Cristian Gafton <gafton@redhat.com>
- fix fsck segfault

* Tue Feb  2 1999 Jeff Johnson <jbj@redhat.com>
- update to 1.14
- use %configure to generate config.sub on arm

* Thu Jan 14 1999 Jeff Johnson <jbj@redhat.com>
- fix /usr/bin/compile_et and doco for com_err.h (#673)

* Thu Jan 07 1999 Cristian Gafton <gafton@redhat.com>
- build with prefix=/usr
- add arm patch

* Mon Dec 28 1998 Jeff Johnson  <jbj@redhat.com>
- update to 1.13.

* Fri Aug 28 1998 Jeff Johnson <jbj@redhat.com>
- recompile statically linked binary for 5.2/sparc

* Mon Jul 13 1998 Jeff Johnson <jbj@redhat.com>
- upgrade to 1.12.

* Thu May 07 1998 Prospector System <bugs@redhat.com>
- translations modified for de, fr, tr

* Thu Apr 30 1998 Cristian Gafton <gafton@redhat.com>
- include <asm/types.h> to match kernel types in utils

* Tue Oct 14 1997 Donnie Barnes <djb@redhat.com>
- spec file cleanups

* Wed Oct 01 1997 Erik Troan <ewt@redhat.com>
- fixed broken llseek() prototype 

* Wed Aug 20 1997 Erik Troan <ewt@redhat.com>
- added patch to prototype llseek

* Tue Jun 17 1997 Erik Troan <ewt@redhat.com>
- built against glibc
